@@ -4,42 +4,43 @@
 #' one or multiple destinations. It implements different cost estimations related to human movement across the landscape.
 #' The function takes as input a Digital Terrain Model ('RasterLayer' class) and a point feature ('SpatialPointsDataFrame' class), the latter representing
 #' the starting location, i.e. the location from which the accumulated cost is calculated. Besides citing this package,
-#' you may want to refer to the following journal article: \strong{Alberti (2019) <doi:10.1016/j.softx.2019.100331>}.\cr
+#' you may want to refer to the following journal article, where an earlier version of the
+#' package is described: \strong{Alberti (2019) <doi:10.1016/j.softx.2019.100331>}.\cr
 #' Visit this \href{https://drive.google.com/file/d/1gLDrkZFh1b_glzCEqKdkPrer72JJ9Ffa/view?usp=sharing}{LINK} to access the package's vignette.\cr
 #'
-#' If the parameter 'destin' is fed with a dataset representing destination location(s) ('SpatialPointsDataFrame' class), the function also calculates
+#' If the parameter \code{destin} is fed with a dataset representing destination location(s) ('SpatialPointsDataFrame' class), the function also calculates
 #' least-cost path(s) plotted on the input DTM; the length of each path is saved under the variable 'length' stored in the 'LCPs' dataset ('SpatialLines' class) returned by the function.
 #' In the produced plot, the red dot(s) representing the destination location(s) are labelled with numeric values representing
 #' the cost value at the location(s). \cr
 #'
 #' The cost value is also appended to the updated destination locations dataset returned by the function, which
-#' stores a new variable labelled 'cost'. If the cost is expressed in terms of walking time, the labels accompaining each destinaton location will
+#' stores a new variable labelled \code{cost}. If the cost is expressed in terms of walking time, the labels accompaining each destinaton location will
 #' express time in sexagesimal numbers (hours, minutes, seconds). In this case, the variable 'cost' appended to the returned destination location datset
-#' will store the time figures in decimal numbers, while another variable named 'cost_hms' will store the corresponding value in sexagesimal numbers.
-#' When interpreting the time values stored in the 'cost' variable, the user may want to bear in mind the selected time unit (see right below).\cr
+#' will store the time figures in decimal numbers, while another variable named \code{cost_hms} will store the corresponding value in sexagesimal numbers.
+#' When interpreting the time values stored in the \code{cost} variable, the user may want to bear in mind the selected time unit (see right below).\cr
 #'
-#' When using cost functions expressing cost in terms of time, the time unit can be selected by the user setting the 'time' parameter to 'h' (hours) or to 'm' (minutes).\cr
+#' When using cost functions expressing cost in terms of time, the time unit can be selected by the user setting the \code{time} parameter to \code{h} (hours) or to \code{m} (minutes).\cr
 #'
-#' In general, the user can also select which type of visualization the function has to produce; this is achieved setting the 'outp' parameter to either 'r' (=raster)
-#' or to 'c' (=contours). The former will produce a raster with a colour scale and contour lines representing the accumulated cost surface; the latter parameter will only
+#' In general, the user can also select which type of visualization the function has to produce; this is achieved setting the \code{outp} parameter to either \code{r} (=raster)
+#' or to \code{c} (=contours). The former will produce a raster with a colour scale and contour lines representing the accumulated cost surface; the latter parameter will only
 #' produce contour lines.\cr
 #'
-#' The contour lines' interval is set using the parameter 'breaks'; if no value is passed to the parameter, the interval will be set by default to
+#' The contour lines' interval is set using the \code{breaks} parameter; if no value is passed to the parameter, the interval will be set by default to
 #' 1/10 of the range of values of the accumulated cost surface.\cr
 #'
 #' It is worth reminding the user(s) that all the input layers (i.e., DTM, start location, and destination locations) must use the same projected coordinate system.\cr
 #'
 #'
 #' \strong{Cost surface calculation}:\cr
-#' for the cost-surface and LCPs calculation, 'movecost' builds on functions from Jacob van Etten's
+#' for the cost-surface and LCPs calculation, \code{movecost()} builds on functions from Jacob van Etten's
 #' \href{https://cran.r-project.org/package=gdistance}{gdistance} package.
-#' Under the hood, 'movecost' calculates the slope as rise over run, following the procedure described
+#' Under the hood, \code{movecost()} calculates the slope as rise over run, following the procedure described
 #' by van Etten, "R Package gdistance: Distances and Routes on Geographical Grids" in Journal of Statistical Software 76(13), 2017, pp. 14-15.
 #' The number of directions in which cells are connected in the cost calculation can be set to 4 (rook's case), 8 (queen's case), or
-#' 16 (knight and one-cell queen moves) using the 'move' parameter (see 'Arguments').\cr
+#' 16 (knight and one-cell queen moves) using the \code{move} parameter (see 'Arguments').\cr
 #'
 #'
-#' \strong{Inibition of movement (barrier)}:\cr
+#' \strong{Inhibition of movement (barrier)}:\cr
 #' areas where the movement is inhibited can be fed into the analysis via the \code{barrier} parameter; SpatialLineDataFrame or SpatialPolygonDataFrame can be used.
 #' The barrier is assigned a conductance value of 0 (i.e., movement is inhibited) by default, but the user can assign any other value via the
 #' \code{field} parameter. Internally, the barrier creation rests on the \code{\link[leastcostpath]{create_barrier_cs}} function
@@ -55,19 +56,46 @@
 #' as a barrier (result3):\cr
 #'
 #' result2 <- movecost(volc, destin.loc[3,], destin.loc[6,], move=8)\cr
-#' result3 <- movecost(volc, destin.loc[3,], destin.loc[6,], barrier=result1$LCPs, move=8)\cr
+#' result3 <- movecost(volc, destin.loc[3,], destin.loc[6,], barrier=result1$LCPs, plot.barrier=TRUE, move=8)\cr
 #'
 #' As apparent by comparing result2 to result3, when the barrier is used (result3), the LCP does not cross the barrier but is "forced"
-#' to make a long detour. \strong{Note} that the \code{move} parameter has been set to 8; if set to 16, the LCP will be "able" to jump the barrier.\cr
+#' to make a long detour. In result3, the barrier is plotted as a blue line. \strong{Note} that the \code{move} parameter has been set to 8; if set to 16, the LCP will be "able" to jump the barrier.\cr
+#'
+#'
+#' \strong{DTM featuring irregular margins}:\cr
+#' if the input DTM features irregular margins, e.g a coastline with gulfs and/or inlets where cells corresponding to the sea are given NoData,
+#' the user is to set the \code{irregular.dtm} parameter to TRUE; this will prevent the LCPs to cross the sea. Internally, what \code{movecost()} does is
+#' to generate a polygon vector layer from the DTM and to use the polygon as a mask to create a Transitional Layer via the
+#' \code{\link[leastcostpath]{create_barrier_cs}} function from the \emph{leastcostpath} package. In the mask Transitional Layer those parts
+#' corresponding to the terrain are given a conductance value equal to 1, while everything else (i.e., the parts corresponding to the sea) are given 0 conductance.
+#' The mask Transitional Layer is then internally multiplied by the conductance transitional layer representing the cost of movement
+#' (according to the user-selected function). This will set to 0 the conductance values of those parts of the study area that do not correspond to the terrain,
+#' while keeping unaltered the conductance of those parts that do coincide with the terrain.\cr
+#'
+#' As a case in point, let's consider the two following examples (using some in-build datasets):\cr
+#'
+#' resultA <- movecost(malta_dtm_40, origin=springs[5,], destin=springs[15,], irregular.dtm=FALSE, oneplot=FALSE)\cr
+#'
+#' resultB <- movecost(malta_dtm_40, origin=springs[5,], destin=springs[15,], irregular.dtm=TRUE, oneplot=FALSE)\cr
+#'
+#' As you can see, in the first case, the LCP between the two locations cross the sea, while in the second case the LCP follows
+#' the coastline. One can also appreciate the difference between the two returned conductance transitional layers:\cr
+#'
+#' plot(raster::raster(resultA$conductance))\cr
+#'
+#' plot(raster::raster(resultB$conductance))\cr
+#'
+#' It is apparent that in the second layer the sea area has been given 0 conductance, while keeping the rest unchanged. If the input DTM does not feature irregular margins (like, for instance, the built-in \code{volc} DTM), the user
+#' may safely leave the \code{irregular.dtm} parameter set to FALSE (which is the default value).\cr
 #'
 #'
 #' \strong{Acquiring online elevation data}:\cr
-#' if a DTM is not provided, 'movecost()' will download elevation data from online sources.
-#' Elevation data will be aquired for the area enclosed  by the  polygon supplied by the 'studyplot' parameter (SpatialPolygonDataFrame class).
-#' To tap online elevation data, 'movecost' internally builds on the
+#' if a DTM is not provided,\code{movecost()}' will download elevation data from online sources.
+#' Elevation data will be acquired for the area enclosed  by the  polygon supplied by the \code{studyplot} parameter (SpatialPolygonDataFrame class).
+#' To tap online elevation data, \code{movecost()}' internally builds on the
 #' \code{\link[elevatr]{get_elev_raster}} function from the \emph{elevatr} package.\cr
 #'
-#' The zoom level of the downloaded DTM (i.e., its resolution) is controlled by the parameter 'z', which is
+#' The zoom level of the downloaded DTM (i.e., its resolution) is controlled by the parameter \code{z}, which is
 #' set to 9 by default (a trade off between resolution and download time).\cr
 #'
 #' To test this facility, the user may want to try the following code, that will generate a least-cost surface and least-cost paths
@@ -95,11 +123,11 @@
 #' following Pingel TJ (2013), Modeling Slope as a Contributor to Route Selection in Mountainous Areas, in Cartography and Geographic Information Science, 37(2), 137-148.
 #' According to Pingel, "Humans tend to overestimate geographic slopes by a surprisingly high margin...This analysis indicates downhill slopes are overestimated
 #' at approximately 2.3 times the vertical, while uphill slopes are overestimated at 2 times the vertical.". As a result,
-#' if the parameter 'cogn.slp' is set to TRUE, positive slope values are preliminarily multiplied by 1.99, while negative slope values are multiplied by 2.31.
+#' if the parameter \code{cogn.slp} is set to \code{TRUE}, positive slope values are preliminarily multiplied by 1.99, while negative slope values are multiplied by 2.31.
 #'
 #'
 #' \strong{Terrain factor (N)}:\cr
-#' virtually all the implemented cost functions (with few exceptions) can take into account a 'terrain factor' (N parameter; 1 by default), which
+#' virtually all the implemented cost functions (with few exceptions) can take into account a 'terrain factor' (\code{N} parameter; 1 by default), which
 #' represents the easiness/difficulty of moving on different terrain types. According to the type of terrain, the energy spent when walking
 #' increases. The same holds true for time, which increases because on a loose terrain (for instance) the walking speed decreases.
 #' While a terrain factor is 'natively' part of the Van Leusen's, Pandolf et al.'s, and Bellavia's cost function,
@@ -110,11 +138,7 @@
 #' Needless to say, if we use a terrain factor of 1.67 with the Tobler's (on-path) hiking function, the results
 #' will be equal to those obtained using the Tobler's off-path function (the reciprocal of 1.67, i.e. 0.60, is in fact
 #' natively used by the Tobler's function for off-path hiking). In fact, compare the results of the following two runs
-#' of 'movecost()' (first some data are loaded):\cr
-#'
-#' volc <- raster::raster(system.file("external/maungawhau.grd", package="gdistance"))\cr
-#' data(volc.loc)\cr
-#' data(destin.loc)\cr
+#' of  \code{movecost()} (using in-built datasets):\cr
 #'
 #' result1 <- movecost(dtm=volc, origin=volc.loc, destin=destin.loc, breaks=0.05, funct="t", N=1.67)\cr
 #' result2 <- movecost(dtm=volc, origin=volc.loc, destin=destin.loc, breaks=0.05, funct="tofp")\cr
@@ -282,6 +306,19 @@
 #'
 #'
 #'
+#' \strong{Tripcevich hiking function (speed in kmh)}:\cr
+#'
+#' \eqn{ ((4.028*46^2)/(((atan(abs(x[adj]))*180/pi)+4.127)^2+46^2))*(1/N) }\cr
+#'
+#' Tripcevich's hiking function; it expresses walking speed in Kmh; slope is originally expressed in degrees;
+#' \strong{see} Tripcevich N (2008). Estimating Llama caravan travel speeds: ethno-archaeological fieldwork with a Peruvian salt caravan.
+#' Trabajo presentado el la inauguracionn del Centre for Spatial Studies, University of California, Santa Barbara.
+#' See also: Lucero G, Marsh EJ, Castro S (2014), Rutas prehistoricas en lo NO de San Juan: una propuesta macroregional desde los sistemas
+#' de information geografica, in Cortegoso V, Duran V, Gasco Alejandra (eds), Arqueologia de ambientes de altura de Mendoza y San
+#' Juan (Argentina), EDIUNC, pp. 275-305.\cr
+#'
+#'
+#'
 #' \strong{Wheeled-vehicle critical slope cost function}:\cr
 #'
 #' \eqn{ 1 / ((1 + ((abs(x[adj])*100) / sl.crit)^2) * N) }\cr
@@ -439,8 +476,10 @@
 #' @param dtm Digital Terrain Model (RasterLayer class); if not provided, elevation data will be acquired online for the area enclosed by the 'studyplot' parameter (see Details).
 #' @param origin location from which the cost surface is calculated (SpatialPointsDataFrame class).
 #' @param destin location(s) to which least-cost path(s) is calculated (SpatialPointsDataFrame class).
-#' @param studyplot polygon (SpatialPolygonDataFrame class) representing the study area for which online elevation data are aquired (see Details); NULL is default.
+#' @param studyplot polygon (SpatialPolygonDataFrame class) representing the study area for which online elevation data are acquired (see Details); NULL is default.
 #' @param barrier area where the movement is inhibited (SpatialLineDataFrame or SpatialPolygonDataFrame class).
+#' @param plot.barrier TRUE or FALSE (default) if the user wants or does not want the barrier to be plotted (in blue).
+#' @param irregular.dtm TRUE or FALSE (default) if the input DTM features irregular margins (Details).
 #' @param funct cost function to be used:\cr
 #'
 #' \strong{-functions expressing cost as walking time-}\cr
@@ -457,6 +496,7 @@
 #' \strong{gkrs} uses the Garmy, Kaddouri, Rozenblat, and Schneider's hiking function;\cr
 #' \strong{r} uses the Rees' hiking function;\cr
 #' \strong{ks} uses the Kondo-Seino's hiking function;\cr
+#' \strong{trp} uses the Tripcevich's hiking function;\cr
 #'
 #' \strong{-functions for wheeled-vehicles-}\cr
 #' \strong{wcs} uses the wheeled-vehicle critical slope cost function;\cr
@@ -474,12 +514,11 @@
 #' \strong{vl} uses the Van Leusen's metabolic energy expenditure cost function;\cr
 #' \strong{ls} uses the Llobera-Sluckin's metabolic energy expenditure cost function;\cr
 #' \strong{a} uses the Ardigo et al.'s metabolic energy expenditure cost function;\cr
-#' \strong{h} uses the Hare's metabolic energy expenditure cost function (for all the mentioned cost functions, see Details);\cr
-#' @param time time-unit expressed by the accumulated raster and by the isolines if Tobler's and other time-related cost functions are used;
-#' 'h' for hour, 'm' for minutes.
+#' \strong{h} uses the Hare's metabolic energy expenditure cost function (for all the mentioned cost functions, see Details).\cr
+#' @param time time-unit expressed by the accumulated raster and by the isolines if Tobler's and other time-related cost functions are used; 'h' for hour, 'm' for minutes.
 #' @param outp type of output: 'raster' or 'contours' (see Details).
 #' @param move number of directions in which cells are connected: 4 (rook's case), 8 (queen's case), 16 (knight and one-cell queen moves; default).
-#' @param field value assigned to the cells coincidinng with the barrier (0 by default).
+#' @param field value assigned to the cells coinciding with the barrier (0 by default).
 #' @param cogn.slp  TRUE or FALSE (default) if the user wants or does not want the 'cognitive slope' to be used in place of the real slope (see Details).
 #' @param sl.crit critical slope (in percent), typically in the range 8-16 (10 by default) (used by the wheeled-vehicle cost function; see Details).
 #' @param W walker's body weight (in Kg; 70 by default; used by the Pandolf's and Van Leusen's cost function; see Details).
@@ -495,7 +534,7 @@
 #' @param cex.breaks set the size of the cost labels used in the contour plot (0.6 by default).
 #' @param cex.lcp.lab set the size of the labels used in least-cost path(s) plot (0.6 by default).
 #' @param graph.out TRUE (default) or FALSE if the user wants or does not want a graphical output to be generated.
-#' @param transp set the transparency of the hillshade raster that is plotted over the rendered plots (0.5 by default).
+#' @param transp set the transparency of the slopeshade raster that is plotted over the rendered plots (0.5 by default).
 #' @param oneplot TRUE (default) or FALSE if the user wants or does not want the plots displayed in a single window.
 #' @param export TRUE or FALSE (default) if the user wants or does not want the outputs to be exported; if TRUE, the DTM, the cost-surface, and the accumulated cost surface are
 #' exported as a GeoTiff file, while the isolines, the least-cost path(s), and a copy of the input destination locations (storing the cost measured at each location)
@@ -514,18 +553,20 @@
 ##'  \item{dest.loc.w.cost: }{copy of the input destination location(s) dataset with a new variable ('cost') added; if
 ##'  the cost is expressed in terms of time, the 'cost' variable will store the time values in decimal numbers, while another variable named
 ##'  'cost_hms' will store the time values in sexagesimmal numbers (hours, minutes, seconds)}
-##'  \item{conductance: }{conductance 'Transitional Layer', returned because internally used by the 'movenetw()' function}
+##'  \item{conductance: }{conductance 'Transitional Layer', returned because internally used by the \code{movenetw()} function}
 ##' }
 ##'
 ##'
 #' @keywords movecost
 #' @export
-#' @importFrom raster ncell mask crop raster hillShade terrain
+#' @importFrom raster ncell mask crop raster terrain focal
 #' @importFrom elevatr get_elev_raster
 #' @importFrom chron times
 #' @importFrom grDevices terrain.colors topo.colors grey
 #' @importFrom graphics layout par
 #' @importFrom leastcostpath create_barrier_cs
+#' @importFrom terra as.polygons
+#' @importFrom stats na.omit
 #'
 #'
 #' @examples
@@ -565,10 +606,10 @@
 #' results <- movecost(dtm=volc, origin=volc.loc, destin=destin.loc[2,], move=8, return.base = TRUE)
 #'
 #'
-#' @seealso \code{\link[elevatr]{get_elev_raster}}, \code{\link{movecorr}}, \code{\link{movebound}}, \code{\link{movealloc}},  \code{\link{movecomp}}, \code{\link{movenetw}}
+#' @seealso \code{\link[elevatr]{get_elev_raster}}, \code{\link{movecorr}}, \code{\link{movebound}}, \code{\link{movealloc}},  \code{\link{movecomp}}, \code{\link{movenetw}}, \code{\link{moverank}}
 #'
 #'
-movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NULL, funct="t", time="h", outp="r", move=16, field=0, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, return.base=FALSE, rb.lty=2, breaks=NULL, cont.lab=TRUE, destin.lab=TRUE, cex.breaks=0.6, cex.lcp.lab=0.6, graph.out=TRUE, transp=0.5, oneplot=TRUE, export=FALSE){
+movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NULL, plot.barrier=FALSE, irregular.dtm=FALSE, funct="t", time="h", outp="r", move=16, field=0, cogn.slp=FALSE, sl.crit=10, W=70, L=0, N=1, V=1.2, z=9, return.base=FALSE, rb.lty=2, breaks=NULL, cont.lab=TRUE, destin.lab=TRUE, cex.breaks=0.6, cex.lcp.lab=0.6, graph.out=TRUE, transp=0.5, oneplot=TRUE, export=FALSE){
 
   #deactivate the warning messages because a warning that can be safely ignored will be produced by the procedure
   #used to get slope as rise over run
@@ -955,8 +996,20 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
     sub.title.lcp.plot <- paste0("LCP(s) and cost distance(s) based on the Eastman's cost function \n terrain factor N=", N, "\nblack dot=start location\n red dot(s)=destination location(s)")
   }
 
+  if(funct=="trp") {
+    #Tripcevich's slope-dependant hiking function; speed in kmh;
+    #slope is originally in degrees; (atan(abs(x[adj]))*180/pi) turns rise/run into degrees
+    cost_function <- function(x){((4.028*46^2)/(((atan(abs(x[adj]))*180/pi)+4.127)^2+46^2))*(1/N) }
+
+    #set the labels to be used within the returned plot
+    main.title <- paste0("Walking-time isochrones (in ", time, ") around origin")
+    sub.title <- paste0("Walking-time based on the Tripcevich's hiking function \n terrain factor N=", N)
+    legend.cost <- paste0("walking-time (", time,")")
+    sub.title.lcp.plot <- paste0("LCP(s) and walking-time distance(s) based on the Tripcevich's hiking function \n terrain factor N=", N, "\nblack dot=start location\n red dot(s)=destination location(s)")
+  }
+
   #cost calculation for walking-speed-based cost functions
-  if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks") {
+  if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="trp") {
 
     #restrict the speed calculation to adjacent cells by creating an index for adjacent cells (adj) with the function 'adjacent'
     adj <- raster::adjacent(dtm, cells=1:raster::ncell(dtm), pairs=TRUE, directions=move)
@@ -972,6 +1025,33 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
     #correct the speed values taking into account the distance between cell centers
     Conductance <- gdistance::geoCorrection(speed)
 
+    if (irregular.dtm==TRUE) {
+      dtm.copy <- dtm
+
+      #substitute the values of the copy with a single value, omitting the NA cells
+      dtm.copy[na.omit(dtm.copy)] <- 1
+
+      #run a 3x3 mean filter to remove possible in-land NoData value because they would prevent the following
+      #step from running
+      dtm.copy <- raster::focal(dtm.copy, w=matrix(1/9,nrow=3,ncol=3))
+
+      #convert the modified dtm copy to a polygon ignoring the NA cells and dissolving cells with the same
+      #attribute (that is all, since we changed all the values to 1) into a single polygon;
+      #as(dtm.copy, "SpatRaster") is needed because 'terra::as.polygons()' requires a SpatRaster layer (not Raster)
+      mask.polyg <- terra::as.polygons(as(dtm.copy, "SpatRaster"), dissolve=TRUE)
+
+      #turn the SpatVector format (returned by terra::as.polygons()) into a SpatialPolygonDataFrame that will be fed into
+      #leastcostpath::create_barrier_cs
+      mask.polyg<-as(mask.polyg, "Spatial")
+
+      #create a Transitional Layer where the masked area is given 1, while the other parts are given 0;
+      #thus all which is not terrain will be given 0 conductance
+      mask.TL <- leastcostpath::create_barrier_cs(dtm.copy, mask.polyg, neighbours = move, field=1, background = 0)
+
+      #use map algebra to "combine" the two Transitional Layers
+      Conductance <- Conductance*mask.TL
+    }
+
     #if the 'barrier' parameter in not NULL...
     if (is.null(barrier)==FALSE) {
       #...create a barrier transitional layers via the 'create_barrier_cs' function
@@ -985,7 +1065,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
   }
 
   #cost calculation for OTHER TYPES of cost functions;
-  #note the Uriarte Gonzalez's and Marin Arroyo's slope-dependant walking-time cost function are in this group since (unlike the above functions)
+  #NOTE the Uriarte Gonzalez's and Marin Arroyo's slope-dependant walking-time cost function are in this group since (unlike the above functions)
   #they expresses cost as time NOT speed
   if (funct=="ree" | funct=="hrz" | funct=="wcs" | funct=="vl" | funct=="p" | funct=="ug" | funct=="ls" | funct=="b" | funct=="m" | funct=="ma" | funct=="a" | funct=="pcf" | funct=="h" | funct=="e") {
 
@@ -1000,6 +1080,33 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
     #correct the cost values taking into account the distance between cell centers
     Conductance <- gdistance::geoCorrection(cost)
 
+    if (irregular.dtm==TRUE) {
+      dtm.copy <- dtm
+
+      #substitute the values of the copy with a single value, omitting the NA cells
+      dtm.copy[na.omit(dtm.copy)] <- 1
+
+      #run a 3x3 mean filter to remove possible in-land NoData value because they would prevent the following
+      #step from running
+      dtm.copy <- raster::focal(dtm.copy, w=matrix(1/9,nrow=3,ncol=3))
+
+      #convert the modified dtm copy to a polygon ignoring the NA cells and dissolving cells with the same
+      #attribute (that is all, since we changed all the values to 1) into a single polygon;
+      #as(dtm.copy, "SpatRaster") is needed because 'terra::as.polygons()' requires a SpatRaster layer (not Raster)
+      mask.polyg <- terra::as.polygons(as(dtm.copy, "SpatRaster"), dissolve=TRUE)
+
+      #turn the SpatVector format (returned by terra::as.polygons()) into a SpatialPolygonDataFrame that will be fed into
+      #leastcostpath::create_barrier_cs
+      mask.polyg<-as(mask.polyg, "Spatial")
+
+      #create a Transitional Layer where the masked area is given 1, while the other parts are given 0;
+      #thus all which is not terrain will be given 0 conductance
+      mask.TL <- leastcostpath::create_barrier_cs(dtm.copy, mask.polyg, neighbours = move, field=1, background = 0)
+
+      #use map algebra to "combine" the two Transitional Layers
+      Conductance <- Conductance*mask.TL
+    }
+
     #if the 'barrier' parameter in not NULL...
     if (is.null(barrier)==FALSE) {
       #...create a barrier transitional layers via the 'create_barrier_cs' function
@@ -1017,7 +1124,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
 
   #if user select the Tobler's, the modified Tobler's, the Irmischer-Clarke's,
   #the Uriarte Gonzalez's, the Alberti's function, or other speed-related functions, turn seconds into the user-defined time-scale
-  if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="ug" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="ma"){
+  if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="ug" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="ma" | funct=="trp"){
     if (time=="h") {
       #turn seconds into hours
       accum_final <- accum_final / 3600
@@ -1048,11 +1155,9 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
 
   if (graph.out==TRUE) {
 
-    #produce the ingredients for the hillshade raster
+    #produce the ingredient for the slopeshade raster
     #to be used in both the rendered plots
     slope <- raster::terrain(dtm, opt = "slope")
-    aspect <- raster::terrain(dtm, opt = "aspect")
-    hill <- raster::hillShade(slope, aspect, angle = 45, direction = 0)
 
     #conditionally set the layout in just one visualization
     if(is.null(destin)==FALSE & oneplot==TRUE){
@@ -1071,9 +1176,9 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
                    legend.lab=legend.cost,
                    col = topo.colors(255))
 
-      #add the hillshade
-      raster::plot(hill,
-                   col = grey(0:100/100),
+      #add the slopeshade
+      raster::plot(slope,
+                   col = rev(grey(0:100/100)),
                    legend = FALSE,
                    alpha=transp,
                    add=TRUE)
@@ -1143,9 +1248,9 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
                    cex.sub=0.7,
                    legend.lab="Elevation (masl)")
 
-      #add the hillshade
-      raster::plot(hill,
-                   col = grey(0:100/100),
+      #add the slopeshade
+      raster::plot(slope,
+                   col = rev(grey(0:100/100)),
                    legend = FALSE,
                    alpha=transp,
                    add=TRUE)
@@ -1168,6 +1273,11 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
                    add=TRUE,
                    pch=20,
                    col="red")
+
+      #if the barrier is provided AND if plot.barrier is TRUE, add the barrier
+      if(is.null(barrier)==FALSE & plot.barrier==TRUE) {
+        raster::plot(barrier, col="blue", add=TRUE)
+      }
     }
 
     #calculate the length of the least-cost paths and store the values by appending them to a new variable of the sPath object
@@ -1183,7 +1293,7 @@ movecost <- function (dtm=NULL, origin, destin=NULL, studyplot=NULL, barrier=NUL
 
     #if user select the Tobler's, the modified Tobler's, the Irmischer-Clarke's,
     #the Uriarte Gonzalez's, the Alberti's function, or other functions producing time cost...
-    if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="ug" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="ma"){
+    if (funct=="t" | funct=="tofp" | funct=="mp" | funct=="icmonp" | funct=="icmoffp" | funct=="icfonp" | funct=="icfoffp" | funct=="ug" | funct=="alb" | funct=="gkrs" | funct=="r" | funct=="ks" | funct=="ma" | funct=="trp"){
       #create a new columns in the 'destin' layer to store decimal hours turned into sessagesimal format
       if (time=="h") {
         destin$cost_hms <- as.character(chron::times(destin$cost / 24))
